@@ -26,10 +26,11 @@ def centroid_com(data, mask=None):
 
     Parameters
     ----------
-    data : array_like
-        The input n-dimensional array.
+    data : `~numpy.ndarray`
+        The input n-dimensional array. The image should be a
+        background-subtracted cutout image containing a single source.
 
-    mask : array_like (bool), optional
+    mask : bool `~numpy.ndarray`, optional
         A boolean mask, with the same shape as ``data``, where a `True`
         value indicates the corresponding element of ``data`` is masked.
 
@@ -39,7 +40,8 @@ def centroid_com(data, mask=None):
         The coordinates of the centroid in pixel order (e.g., ``(x, y)``
         or ``(x, y, z)``), not numpy axis order.
     """
-    data = data.astype(float)
+    # preserve input data - which should be a small cutout image
+    data = data.copy()
 
     if mask is not None and mask is not np.ma.nomask:
         mask = np.asarray(mask, dtype=bool)
@@ -91,8 +93,9 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
 
     Parameters
     ----------
-    data : `~numpy.ndarray`
-        Image data.
+    data : 2D `~numpy.ndarray`
+        The 2D image data. The image should be a background-subtracted
+        cutout image containing a single source.
 
     xpeak, ypeak : float or `None`, optional
         The initial guess of the position of the centroid. If either
@@ -159,25 +162,27 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
     if ypeak is not None and ((ypeak < 0) or (ypeak > data.shape[0] - 1)):
         raise ValueError('ypeak is outside of the input data')
 
+    # preserve input data - which should be a small cutout image
     data = np.asanyarray(data, dtype=float).copy()
     ny, nx = data.shape
 
     badmask = ~np.isfinite(data)
+    if mask is not None:
+        if data.shape != mask.shape:
+            raise ValueError('data and mask must have the same shape.')
+        data[mask] = np.nan
+        badmask &= ~mask
+
     if np.any(badmask):
         warnings.warn('Input data contains non-finite values (e.g., NaN or '
                       'inf) that were automatically masked.',
                       AstropyUserWarning)
         data[badmask] = np.nan
 
-    if mask is not None:
-        if data.shape != mask.shape:
-            raise ValueError('data and mask must have the same shape.')
-        data[mask] = np.nan
-
     fit_boxsize = as_pair('fit_boxsize', fit_boxsize, lower_bound=(0, 1),
                           upper_bound=data.shape, check_odd=True)
 
-    if np.product(fit_boxsize) < 6:
+    if np.prod(fit_boxsize) < 6:
         raise ValueError('fit_boxsize is too small.  6 values are required '
                          'to fit a 2D quadratic polynomial.')
 
@@ -239,6 +244,12 @@ def centroid_quadratic(data, xpeak=None, ypeak=None, fit_boxsize=5,
     y = y.ravel()
     coeff_matrix = np.vstack((np.ones_like(x), x, y, x * y, x * x, y * y)).T
 
+    # remove NaNs from data to be fit
+    mask = ~np.isnan(cutout)
+    if np.any(mask):
+        coeff_matrix = coeff_matrix[mask]
+        cutout = cutout[mask]
+
     try:
         c = np.linalg.lstsq(coeff_matrix, cutout, rcond=None)[0]
     except np.linalg.LinAlgError:
@@ -277,15 +288,15 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None, mask=None,
 
     Parameters
     ----------
-    data : array_like
-        The 2D array of the image.
+    data : 2D `~numpy.ndarray`
+        The 2D image data. The image should be background-subtracted.
 
-    xpos, ypos : float or array-like of float
+    xpos, ypos : float or array_like of float
         The initial ``x`` and ``y`` pixel position(s) of the center
         position.  A cutout image centered on this position be used to
         calculate the centroid.
 
-    box_size : int or array-like of int, optional
+    box_size : int or array_like of int, optional
         The size of the cutout image along each axis. If ``box_size`` is
         a number, then a square cutout of ``box_size`` will be created.
         If ``box_size`` has two elements, they must be in ``(ny, nx)``
@@ -303,12 +314,12 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None, mask=None,
         ``footprint`` must be defined. If they are both defined, then
         ``footprint`` overrides ``box_size``.
 
-    mask : array_like, bool, optional
+    mask : 2D bool `~numpy.ndarray`, optional
         A 2D boolean array with the same shape as ``data``, where a
         `True` value indicates the corresponding element of ``data`` is
         masked.
 
-    error : array_like, optional
+    error : 2D `~numpy.ndarray`, optional
         The 2D array of the 1-sigma errors of the input ``data``.
         ``error`` must have the same shape as ``data``.  ``error`` will
         be used only if supported by the input ``centroid_func``.
@@ -333,6 +344,42 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None, mask=None,
         a ``box_size`` that is too small when using a fitting-based
         centroid function (e.g., `centroid_1dg`, `centroid_2dg`, or
         `centroid_quadratic`.
+
+    Examples
+    --------
+    >>> from photutils.centroids import centroid_com, centroid_sources
+    >>> from photutils.datasets import make_4gaussians_image
+    >>> from photutils.utils import circular_footprint
+    >>> data = make_4gaussians_image()
+
+    >>> x_init = (25, 91, 151, 160)
+    >>> y_init = (40, 61, 24, 71)
+    >>> footprint = circular_footprint(5.0)
+    >>> x, y = centroid_sources(data, x_init, y_init, footprint=footprint,
+    ...                         centroid_func=centroid_com)
+    >>> print(x)  # doctest: +FLOAT_CMP
+    [ 24.9865905   90.84751557 150.50228056 159.74319544]
+    >>> print(y)  # doctest: +FLOAT_CMP
+    [40.01096547 60.92509086 24.52986889 70.57971148]
+
+    .. plot::
+        :include-source:
+
+        import matplotlib.pyplot as plt
+        from photutils.centroids import centroid_com, centroid_sources
+        from photutils.datasets import make_4gaussians_image
+        from photutils.utils import circular_footprint
+        data = make_4gaussians_image()
+        x_init = (25, 91, 151, 160)
+        y_init = (40, 61, 24, 71)
+        footprint = circular_footprint(5.0)
+        x, y = centroid_sources(data, x_init, y_init, footprint=footprint,
+                                centroid_func=centroid_com)
+        plt.figure(figsize=(8, 4))
+        plt.imshow(data, origin='lower', interpolation='nearest')
+        plt.scatter(x, y, marker='+', s=80, color='red', label='Centroids')
+        plt.legend()
+        plt.tight_layout()
     """
     xpos = np.atleast_1d(xpos)
     ypos = np.atleast_1d(ypos)
@@ -386,6 +433,12 @@ def centroid_sources(data, xpos, ypos, box_size=11, footprint=None, mask=None,
         else:
             mask_cutout = footprint_mask
 
+        if np.all(mask_cutout):
+            raise ValueError(f'The cutout for the source at ({xp, yp}) is '
+                             'completely masked. Please check your input '
+                             'mask and footprint. Also note that footprint '
+                             'must be a small, local footprint.')
+
         centroid_kwargs.update({'mask': mask_cutout})
 
         error = centroid_kwargs.get('error', None)
