@@ -6,6 +6,7 @@ This module provides models for doing PSF/PRF-fitting photometry.
 import copy
 import itertools
 import warnings
+from functools import lru_cache
 
 import numpy as np
 from astropy.modeling import Fittable2DModel, Parameter
@@ -544,7 +545,7 @@ class EPSFModel(FittableImageModel):
         radius = self._norm_radius * self.oversampling[0]
         aper = CircularAperture(xypos, r=radius)
         flux, _ = aper.do_photometry(self._data, method='exact')
-        return flux[0] / np.product(self.oversampling)
+        return flux[0] / np.prod(self.oversampling)
 
     def _compute_normalization(self, normalize=True):
         """
@@ -759,10 +760,16 @@ class GriddedPSFModel(Fittable2DModel):
         self._ref_indices = None
         self._psf_interp = None
 
+        # NOTE: replace @lru_cache with @cache for Python 3.9+;
+        # Here we avoid decorating the instance method with
+        # @lru_cache/cache to prevent memory leaks
+        self._compute_local_model = lru_cache(maxsize=128)(
+            self._compute_local_model_uncached)
+
         super().__init__(flux, x_0, y_0)
 
     @staticmethod
-    def _find_bounds_1d(data, x):
+    def _find_start_idx(data, x):
         """
         Find the index of the lower bound where ``x`` should be inserted
         into ``a`` to maintain order.
@@ -790,7 +797,6 @@ class GriddedPSFModel(Fittable2DModel):
             idx0 = idx - 2
         else:
             idx0 = idx - 1
-
         return idx0
 
     def _find_bounding_points(self, x, y):
@@ -802,29 +808,22 @@ class GriddedPSFModel(Fittable2DModel):
         ----------
         x, y : float
             The ``(x, y)`` position where the PSF is to be evaluated.
+            The position must be inside the region defined by the grid
+            of PSF positions.
 
         Returns
         -------
         indices : list of int
             A list of indices of the bounding grid points.
         """
-        if not np.isscalar(x) or not np.isscalar(y):  # pragma: no cover
-            raise TypeError('x and y must be scalars')
-
-        if (x < self._xgrid_min
-                or x > self._xgrid_max
-                or y < self._ygrid_min
-                or y > self._ygrid_max):  # pragma: no cover
-            raise ValueError('(x, y) position is outside of the region '
-                             'defined by grid of PSF positions')
-
-        x0 = self._find_bounds_1d(self._xgrid, x)
-        y0 = self._find_bounds_1d(self._ygrid, y)
-        points = list(itertools.product(self._xgrid[x0:x0 + 2],
-                                        self._ygrid[y0:y0 + 2]))
+        x0 = self._find_start_idx(self._xgrid, x)
+        y0 = self._find_start_idx(self._ygrid, y)
+        xypoints = list(itertools.product(self._xgrid[x0:x0 + 2],
+                                          self._ygrid[y0:y0 + 2]))
 
+        # find the grid_xypos indices of the reference xypoints
         indices = []
-        for xx, yy in points:
+        for xx, yy in xypoints:
             indices.append(np.argsort(np.hypot(self._grid_xpos - xx,
                                                self._grid_ypos - yy))[0])
 
@@ -856,13 +855,6 @@ class GriddedPSFModel(Fittable2DModel):
         result : 2D `~numpy.ndarray`
             The 2D interpolated array.
         """
-        if len(xyref) != 4:
-            raise ValueError('xyref must contain only 4 (x, y) pairs')
-
-        if zref.shape[0] != 4:
-            raise ValueError('zref must have a length of 4 on the first '
-                             'axis.')
-
         xyref = [tuple(i) for i in xyref]
         idx = sorted(range(len(xyref)), key=xyref.__getitem__)
         xyref = sorted(xyref)  # sort by x, then y
@@ -887,26 +879,17 @@ class GriddedPSFModel(Fittable2DModel):
 
         return np.sum(data * weights[:, None, None], axis=0) / norm
 
-    def _compute_local_model(self, x_0, y_0):
+    def _compute_local_model_uncached(self, x_0, y_0):
         """
         Return `FittableImageModel` for interpolated PSF at some (x_0, y_0).
         """
-        # NOTE: this is needed because the PSF photometry routines input
-        # length-1 values instead of scalars.  TODO: fix the photometry
-        # routines.
-        if not np.isscalar(x_0):
-            x_0 = x_0[0]
-        if not np.isscalar(y_0):
-            y_0 = y_0[0]
-
         if (x_0 < self._xgrid_min or x_0 > self._xgrid_max
                 or y_0 < self._ygrid_min or y_0 > self._ygrid_max):
-
             # position is outside of the grid, so simply use the
             # closest reference PSF
-            self._ref_indices = np.argsort(np.hypot(self._grid_xpos - x_0,
-                                                    self._grid_ypos - y_0))[0]
-            self._psf_interp = self.data[self._ref_indices, :, :]
+            self._ref_index = np.argsort(np.hypot(self._grid_xpos - x_0,
+                                                  self._grid_ypos - y_0))[0]
+            self._psf_interp = self.data[self._ref_index, :, :]
         else:
             # find the four bounding reference PSFs and interpolate
             self._ref_indices = self._find_bounding_points(x_0, y_0)
@@ -924,8 +907,19 @@ class GriddedPSFModel(Fittable2DModel):
         """
         Evaluate the `GriddedPSFModel` for the input parameters.
         """
-        # Get the local PSF at the (x_0,y_0)
-        psfmodel = self._compute_local_model(x_0, y_0)
+        # NOTE: the astropy base Model.__call__() method converts scalar
+        # inputs to size-1 arrays before calling evaluate().
+        if not np.isscalar(flux):
+            flux = flux[0]
+        if not np.isscalar(x_0):
+            x_0 = x_0[0]
+        if not np.isscalar(y_0):
+            y_0 = y_0[0]
+
+        # Calculate the local (interpolated) PSF at (x_0, y_0) from the
+        # grid of PSF models. Only the integer part of the position is
+        # input so that the local model can be cached.
+        psfmodel = self._compute_local_model(int(x_0), int(y_0))
 
         # now evaluate the PSF at the (x_0, y_0) subpixel position on
         # the input (x, y) values
@@ -1085,6 +1079,13 @@ class PRFAdapter(Fittable2DModel):
 
     def evaluate(self, x, y, flux, x_0, y_0):
         """The evaluation function for PRFAdapter."""
+        if not np.isscalar(flux):
+            flux = flux[0]
+        if not np.isscalar(x_0):
+            x_0 = x_0[0]
+        if not np.isscalar(y_0):
+            y_0 = y_0[0]
+
         if self.xname is None:
             dx = x - x_0
         else:
