@@ -67,7 +67,7 @@ class BasicPSFPhotometry:
         fit. The names of these parameters should be given as ``x_0``,
         ``y_0`` and ``flux``. `~photutils.psf.prepare_psf_model` can be
         used to prepare any 2D model to match this assumption.
-    fitshape : int or length-2 array-like
+    fitshape : int or length-2 array_like
         Rectangular shape around the center of a star that will be
         used to define the PSF-fitting region. If ``fitshape`` is a
         scalar then a square shape of size ``fitshape`` will be used.
@@ -102,7 +102,7 @@ class BasicPSFPhotometry:
         List of additional columns for parameters derived by any of the
         intermediate fitting steps (e.g., ``finder``), such as roundness
         or sharpness.
-    subshape : `None`, int, or length-2 array-like
+    subshape : `None`, int, or length-2 array_like
         Rectangular shape around the center of a star that will be
         used to define the PSF-subtraction region. If `None`, then
         ``fitshape`` will be used. If ``subshape`` is a scalar then a
@@ -526,11 +526,7 @@ class BasicPSFPhotometry:
                                     image[usepixel])
             param_table = self._model_params2table(fit_model, group)
             result_tab = vstack([result_tab, param_table])
-
-            param_cov = self.fitter.fit_info.get('param_cov', None)
-            if param_cov is not None:
-                unc_tab = vstack([unc_tab,
-                                  self._get_uncertainties(len(group))])
+            unc_tab = vstack([unc_tab, self._get_uncertainties(len(group))])
 
             # do not subtract if the fitting did not go well
             try:
@@ -539,8 +535,11 @@ class BasicPSFPhotometry:
             except NoOverlapError:
                 pass
 
-        if param_cov is not None:
-            result_tab = hstack([result_tab, unc_tab])
+        for col in unc_tab.colnames:
+            if np.all(np.isnan(unc_tab[col])):
+                unc_tab.remove_column(col)
+
+        result_tab = hstack([result_tab, unc_tab])
 
         return result_tab, image
 
@@ -610,8 +609,12 @@ class BasicPSFPhotometry:
         with warnings.catch_warnings():
             warnings.simplefilter('ignore', RuntimeWarning)
             for i in range(star_group_size):
-                unc_tab[i] = np.sqrt(np.diag(param_cov))[k: k + n_fit_params]
-                k = k + n_fit_params
+                if param_cov is None:
+                    unc_tab[i] = [np.nan] * n_fit_params
+                else:
+                    sig = np.sqrt(np.diag(param_cov))
+                    unc_tab[i] = sig[k: k + n_fit_params]
+                    k += n_fit_params
 
         return unc_tab
 
@@ -701,7 +704,7 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
         fit. The names of these parameters should be given as ``x_0``,
         ``y_0`` and ``flux``. `~photutils.psf.prepare_psf_model` can be
         used to prepare any 2D model to match this assumption.
-    fitshape : int or length-2 array-like
+    fitshape : int or length-2 array_like
         Rectangular shape around the center of a star that will be
         used to define the PSF-fitting region. If ``fitshape`` is a
         scalar then a square shape of size ``fitshape`` will be used.
@@ -737,7 +740,7 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
         List of additional columns for parameters derived by any of the
         intermediate fitting steps (e.g., ``finder``), such as roundness
         or sharpness.
-    subshape : `None`, int, or length-2 array-like
+    subshape : `None`, int, or length-2 array_like
         Rectangular shape around the center of a star that will be
         used to define the PSF-subtraction region. If `None`, then
         ``fitshape`` will be used. If ``subshape`` is a scalar then a
@@ -862,7 +865,8 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
 
             # n_start = 2 because it starts in the second iteration
             # since the first iteration is above
-            output_table = self._do_photometry(n_start=2, mask=mask)
+            output_table = self._do_photometry(n_start=2, mask=mask,
+                                               progress_bar=progress_bar)
             output_table = vstack([table, output_table])
         else:
             if self.bkg_estimator is not None:
@@ -873,13 +877,14 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
             if self.aperture_radius is None:
                 self.set_aperture_radius()
 
-            output_table = self._do_photometry(mask=mask)
+            output_table = self._do_photometry(mask=mask,
+                                               progress_bar=progress_bar)
 
         output_table.meta = {'version': _get_version_info()}
 
         return QTable(output_table)
 
-    def _do_photometry(self, n_start=1, mask=None):
+    def _do_photometry(self, n_start=1, mask=None, progress_bar=False):
         """
         Helper function which performs the iterations of the photometry
         process.
@@ -932,7 +937,8 @@ class IterativelySubtractedPSFPhotometry(BasicPSFPhotometry):
 
             star_groups = self.group_maker(init_guess_tab)
             table, self._residual_image = super().nstar(
-                self._residual_image, star_groups, mask=mask)
+                self._residual_image, star_groups, mask=mask,
+                progress_bar=progress_bar)
 
             star_groups = star_groups.group_by('group_id')
             table = hstack([star_groups, table])
@@ -996,7 +1002,7 @@ class DAOPhotPSFPhotometry(IterativelySubtractedPSFPhotometry):
         fit. The names of these parameters should be given as ``x_0``,
         ``y_0`` and ``flux``. `~photutils.psf.prepare_psf_model` can be
         used to prepare any 2D model to match this assumption.
-    fitshape : int or length-2 array-like
+    fitshape : int or length-2 array_like
         Rectangular shape around the center of a star that will be
         used to define the PSF-fitting region. If ``fitshape`` is a
         scalar then a square shape of size ``fitshape`` will be used.
@@ -1044,7 +1050,7 @@ class DAOPhotPSFPhotometry(IterativelySubtractedPSFPhotometry):
         List of additional columns for parameters derived by any of the
         intermediate fitting steps (e.g., ``finder``), such as roundness
         or sharpness.
-    subshape : `None`, int, or length-2 array-like
+    subshape : `None`, int, or length-2 array_like
         Rectangular shape around the center of a star that will be
         used to define the PSF-subtraction region. If `None`, then
         ``fitshape`` will be used. If ``subshape`` is a scalar then a
