@@ -11,7 +11,8 @@ from numpy.testing import assert_allclose, assert_equal
 
 from photutils.segmentation.core import Segment, SegmentationImage
 from photutils.utils import circular_footprint
-from photutils.utils._optional_deps import HAS_MATPLOTLIB, HAS_SCIPY
+from photutils.utils._optional_deps import (HAS_MATPLOTLIB, HAS_RASTERIO,
+                                            HAS_SCIPY, HAS_SHAPELY)
 
 
 @pytest.mark.skipif(not HAS_SCIPY, reason='scipy is required')
@@ -357,38 +358,35 @@ class TestSegmentationImage:
         segm_array = np.zeros((7, 7)).astype(int)
         segm_array[3, 3] = 1
         segm = SegmentationImage(segm_array)
+        mask = segm.make_source_mask()
+        assert_equal(mask, segm_array.astype(bool))
+
+        mask = segm.make_source_mask(size=3)
+        expected1 = np.array([[0, 0, 0, 0, 0, 0, 0],
+                              [0, 0, 0, 0, 0, 0, 0],
+                              [0, 0, 1, 1, 1, 0, 0],
+                              [0, 0, 1, 1, 1, 0, 0],
+                              [0, 0, 1, 1, 1, 0, 0],
+                              [0, 0, 0, 0, 0, 0, 0],
+                              [0, 0, 0, 0, 0, 0, 0]])
+        assert_equal(mask.astype(int), expected1)
+
+        mask = segm.make_source_mask(footprint=np.ones((3, 3)))
+        assert_equal(mask.astype(int), expected1)
+
         footprint = circular_footprint(radius=3)
         mask = segm.make_source_mask(footprint=footprint)
-        expected = np.array([[0, 0, 0, 1, 0, 0, 0],
-                             [0, 1, 1, 1, 1, 1, 0],
-                             [0, 1, 1, 1, 1, 1, 0],
-                             [1, 1, 1, 1, 1, 1, 1],
-                             [0, 1, 1, 1, 1, 1, 0],
-                             [0, 1, 1, 1, 1, 1, 0],
-                             [0, 0, 0, 1, 0, 0, 0]])
-        assert_equal(mask.astype(int), expected)
+        expected2 = np.array([[0, 0, 0, 1, 0, 0, 0],
+                              [0, 1, 1, 1, 1, 1, 0],
+                              [0, 1, 1, 1, 1, 1, 0],
+                              [1, 1, 1, 1, 1, 1, 1],
+                              [0, 1, 1, 1, 1, 1, 0],
+                              [0, 1, 1, 1, 1, 1, 0],
+                              [0, 0, 0, 1, 0, 0, 0]])
+        assert_equal(mask.astype(int), expected2)
 
-        mask = segm.make_source_mask(footprint=None)
-        assert_equal(mask, segm.data.astype(bool))
-
-    def test_outline_segments(self):
-        segm_array = np.zeros((5, 5)).astype(int)
-        segm_array[1:4, 1:4] = 2
-        segm = SegmentationImage(segm_array)
-        segm_array_ref = np.copy(segm_array)
-        segm_array_ref[2, 2] = 0
-        assert_allclose(segm.outline_segments(), segm_array_ref)
-
-    def test_outline_segments_masked_background(self):
-        segm_array = np.zeros((5, 5)).astype(int)
-        segm_array[1:4, 1:4] = 2
-        segm = SegmentationImage(segm_array)
-        segm_array_ref = np.copy(segm_array)
-        segm_array_ref[2, 2] = 0
-        segm_outlines = segm.outline_segments(mask_background=True)
-        assert isinstance(segm_outlines, np.ma.MaskedArray)
-        assert np.ma.count(segm_outlines) == 8
-        assert np.ma.count_masked(segm_outlines) == 17
+        mask = segm.make_source_mask(footprint=np.ones((3, 3)), size=5)
+        assert_equal(mask, expected1)
 
     @pytest.mark.skipif(not HAS_MATPLOTLIB, reason='matplotlib is required')
     def test_imshow(self):
@@ -397,6 +395,38 @@ class TestSegmentationImage:
         axim = self.segm.imshow(figsize=(5, 5))
         assert isinstance(axim, AxesImage)
 
+    @pytest.mark.skipif(not HAS_RASTERIO, reason='rasterio is required')
+    @pytest.mark.skipif(not HAS_SHAPELY, reason='shapely is required')
+    def test_polygons(self):
+        from shapely.geometry.polygon import Polygon
+
+        polygons = self.segm.polygons
+        assert len(polygons) == self.segm.nlabels
+        assert isinstance(polygons[0], Polygon)
+
+    @pytest.mark.skipif(not HAS_RASTERIO, reason='rasterio is required')
+    @pytest.mark.skipif(not HAS_MATPLOTLIB, reason='matplotlib is required')
+    def test_patches(self):
+        from matplotlib.patches import Polygon
+
+        patches = self.segm.to_patches(edgecolor='blue')
+        assert isinstance(patches[0], Polygon)
+        assert patches[0].get_edgecolor() == (0, 0, 1, 1)
+
+        patches = self.segm.plot_patches(edgecolor='red')
+        assert isinstance(patches[0], Polygon)
+        assert patches[0].get_edgecolor() == (1, 0, 0, 1)
+
+        patches = self.segm.plot_patches(labels=1)
+        assert len(patches) == 1
+        assert isinstance(patches, list)
+        assert isinstance(patches[0], Polygon)
+
+        patches = self.segm.plot_patches(labels=(4, 7))
+        assert len(patches) == 2
+        assert isinstance(patches, list)
+        assert isinstance(patches[0], Polygon)
+
 
 class CustomSegm(SegmentationImage):
     @lazyproperty
